<?php

namespace Drupal\niobi_app\Plugin\niobi_app\ApplicationDecision;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\niobi_app\Entity\NiobiApplication;
use Symfony\Component\HttpFoundation\RedirectResponse;

/**
 * @NiobiAppDecision (
 *   id = "close_application",
 *   label = @Translation("Close the application and complete workflow"),
 * )
 */
class CloseApplication {

  public static function processDecision(FormStateInterface $form_state, NiobiApplication $application) {
    $application->set('field_decision', $form_state->getValue('decision'));
    $application->set('field_decision_notes', $form_state->getValue('decision_notes'));
    $application->set('field_decision_notes', $form_state->getValue('decision_notes'));
    $application->set('field_application_status', 'complete');
    $application->save();

    $send = $form_state->getValue('send_email');
    if (isset($send['send']) && $send['send'] === 'send') {
      $to = $application->getOwner()->getEmail();
      if ($to) {
        $module = 'niobi_app';
        $key = 'niobi_app_mail';
        $langcode = \Drupal::currentUser()->getPreferredLangcode();
        $params = [
          'from' => \Drupal::config('system.site')->get('mail'),
          'subject' => $form_state->getValue('decision'),
          'message' => $form_state->getValue('decision_notes'),
        ];
        $reply = NULL;
        $send = TRUE;
        $mailManager = \Drupal::service('plugin.manager.mail');
        $result = $mailManager->mail($module, $key, $to, $langcode, $params, $reply, $send);
      }
    }

    $url = $application->toUrl('canonical');
    $form_state->setRedirectUrl($url);
  }

  public static function alterDecisionForm(array $form, FormStateInterface $form_state, NiobiApplication $application) {

    $form['send_email'] = [
      '#type' => 'checkboxes',
      '#title' => t('Send decision to applicant by email'),
      '#description' => t('An email will be sent to the applicant with the decision as subject and decision notes as the body.'),
      '#options' => [
        'send' => 'Send',
      ],
    ];
    $form['decision'] = [
      '#type' => 'textfield',
      '#title' => t('Decision'),
      '#placeholder' => t('A brief summary statement of the decision, i.e. "accept without reservation."'),
    ];
    $form['decision_notes'] = [
      '#type' => 'text_format',
      '#title' => t('Decision Notes'),
    ];

    return $form;
  }

}