<?php

namespace Drupal\niobi_app\Plugin\views\access;

use Drupal\Core\Session\AccountInterface;
use Drupal\niobi_app\Entity\NiobiApplicationWorkflow;
use Drupal\views\Plugin\views\access\AccessPluginBase;
use Symfony\Component\Routing\Route;

/**
 * Access plugin that provides no access control at all.
 *
 * @ingroup views_access_plugins
 *
 * @ViewsAccess(
 *   id = "niobi_app_workflow_admin",
 *   title = @Translation("User is an Application Workflow Admin"),
 *   help = @Translation("Render a nominate/apply action")
 * )
 */
class NiobiAppWorkflowAdmin extends AccessPluginBase {

  /**
   * {@inheritdoc}
   */
  public function summaryTitle() {
    return $this->t('User is an Application Workflow Admin');
  }

  /**
   * {@inheritdoc}
   */
  public function access(AccountInterface $account) {
    $workflow_id = \Drupal::routeMatch()->getParameter('niobi_application_workflow');
    if($workflow_id) {
      $workflow = NiobiApplicationWorkflow::load($workflow_id);
      $workflow_author = $workflow->getOwner();
      $is_author = $workflow_author->id() === $account->id();
      $permission = $account->hasPermission('administer niobi_app applications');
      return $is_author || $permission;
    }
    // If we don't have a workflow ID, then we can't grant access.
    return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public function alterRouteDefinition(Route $route) {
    // We don't have anything to change at this time.
    $route->setRequirement('_niobi_app_workflow_admin', 'TRUE');
  }

}
